@@ -1,16 +1,15 @@
 import logging
 import os
 import sys
+from pathlib import Path
 from typing import Any, Dict, List, Tuple
-
-from PyQt5 import QtCore
-from PyQt5.QtWidgets import QMessageBox
-
+from PyQt6 import QtCore
+from PyQt6.QtWidgets import QMessageBox
 from vorta.borg.break_lock import BorgBreakJob
 from vorta.borg.create import BorgCreateJob
 from vorta.borg.jobs_manager import JobsManager
 from vorta.borg.version import BorgVersionJob
-from vorta.config import PROFILE_BOOTSTRAP_FILE, TEMP_DIR
+from vorta.config import LOG_DIR, PROFILE_BOOTSTRAP_FILE, TEMP_DIR
 from vorta.i18n import init_translations, translate
 from vorta.notifications import VortaNotifications
 from vorta.profile_export import ProfileExport
@@ -24,7 +23,7 @@ from vorta.views.main_window import MainWindow
 
 logger = logging.getLogger(__name__)
 
-APP_ID = os.path.join(TEMP_DIR, "socket")
+APP_ID = TEMP_DIR / "socket"
 
 
 class VortaApp(QtSingleApplication):
@@ -43,16 +42,16 @@ class VortaApp(QtSingleApplication):
     check_failed_event = QtCore.pyqtSignal(dict)
 
     def __init__(self, args_raw, single_app=False):
-        super().__init__(APP_ID, args_raw)
+        super().__init__(str(APP_ID), args_raw)
         args = parse_args()
         if self.isRunning():
             if single_app:
                 self.sendMessage("open main window")
-                print('An instance of Vorta is already running. Opening main window.')
+                logger.info('An instance of Vorta is already running. Opening main window.')
                 sys.exit()
             elif args.profile:
                 self.sendMessage(f"create {args.profile}")
-                print('Creating backup using existing Vorta instance.')
+                logger.info('Creating backup using existing Vorta instance.')
                 sys.exit()
         elif args.profile:
             sys.exit('Vorta must already be running for --create to work')
@@ -88,8 +87,6 @@ class VortaApp(QtSingleApplication):
         if sys.platform == 'darwin':
             self.check_darwin_permissions()
 
-        self.installEventFilter(self)
-
     def create_backups_cmdline(self, profile_name):
         profile = BackupProfileModel.get_or_none(name=profile_name)
         if profile is not None:
@@ -99,16 +96,6 @@ class VortaApp(QtSingleApplication):
         else:
             logger.warning(f"Invalid profile name {profile_name}")
 
-    def eventFilter(self, source, event):
-        if event.type() == QtCore.QEvent.ApplicationPaletteChange and isinstance(source, MainWindow):
-            self.main_window.set_icons()
-            self.main_window.repoTab.set_icons()
-            self.main_window.archiveTab.set_icons()
-            self.main_window.scheduleTab.set_icons()
-        if event.type() == QtCore.QEvent.ApplicationPaletteChange and source == self.tray.contextMenu():
-            self.tray.set_tray_icon()
-        return False
-
     def quit_app_action(self):
         self.backup_cancelled_event.emit()
         del self.main_window
@@ -127,8 +114,12 @@ class VortaApp(QtSingleApplication):
             self.jobs_manager.add_job(job)
         else:
             notifier = VortaNotifications.pick()
-            notifier.deliver(self.tr('Vorta Backup'), translate('messages', msg['message']), level='error')
-            self.backup_progress_event.emit(translate('messages', msg['message']))
+            notifier.deliver(
+                self.tr('Vorta Backup'),
+                translate('messages', msg['message']),
+                level='error',
+            )
+            self.backup_progress_event.emit(f"[{profile.name}] {translate('messages', msg['message'])}")
             return None
 
     def open_main_window_action(self):
@@ -188,10 +179,10 @@ class VortaApp(QtSingleApplication):
 
     def _alert_missing_borg(self):
         msg = QMessageBox()
-        msg.setIcon(QMessageBox.Critical)
+        msg.setIcon(QMessageBox.Icon.Critical)
         msg.setText(self.tr("No Borg Binary Found"))
         msg.setInformativeText(self.tr("Vorta was unable to locate a usable Borg Backup binary."))
-        msg.setStandardButtons(QMessageBox.Ok)
+        msg.setStandardButtons(QMessageBox.StandardButton.Ok)
         msg.exec()
 
     def check_darwin_permissions(self):
@@ -203,19 +194,25 @@ class VortaApp(QtSingleApplication):
         This function tries reading a file that is known to be restricted and warn the user about
         incomplete backups.
         """
-        test_path = os.path.expanduser('~/Library/Cookies')
-        if os.path.exists(test_path) and not os.access(test_path, os.R_OK):
+
+        if not SettingsModel.get(key="check_full_disk_access").value:
+            return
+
+        test_path = Path('~/Library/Cookies').expanduser()
+        if test_path.exists() and not os.access(test_path, os.R_OK):
             msg = QMessageBox()
-            msg.setIcon(QMessageBox.Warning)
-            msg.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse)
+            msg.setIcon(QMessageBox.Icon.Warning)
+            msg.setTextInteractionFlags(QtCore.Qt.TextInteractionFlag.LinksAccessibleByMouse)
             msg.setText(self.tr("Vorta needs Full Disk Access for complete Backups"))
-            msg.setInformativeText(self.tr(
-                "Without this, some files won't be accessible and you may end up with an incomplete "
-                "backup. Please set <b>Full Disk Access</b> permission for Vorta in "
-                "<a href='x-apple.systempreferences:com.apple.preference.security?Privacy'>"
-                "System Preferences > Security & Privacy</a>."
-            ))
-            msg.setStandardButtons(QMessageBox.Ok)
+            msg.setInformativeText(
+                self.tr(
+                    "Without this, some files will not be accessible and you may end up with an incomplete "
+                    "backup. Please set <b>Full Disk Access</b> permission for Vorta in "
+                    "<a href='x-apple.systempreferences:com.apple.preference.security?Privacy'>"
+                    "System Preferences > Security & Privacy</a>."
+                )
+            )
+            msg.setStandardButtons(QMessageBox.StandardButton.Ok)
             msg.exec()
 
     def react_to_log(self, mgs, context):
@@ -228,13 +225,17 @@ class VortaApp(QtSingleApplication):
             repo_url = context.get('repo_url')
             msg = QMessageBox()
             msg.setWindowTitle(self.tr("Repository In Use"))
-            msg.setIcon(QMessageBox.Critical)
-            abortButton = msg.addButton(self.tr("Abort"), QMessageBox.RejectRole)
-            msg.addButton(self.tr("Continue"), QMessageBox.AcceptRole)
+            msg.setIcon(QMessageBox.Icon.Critical)
+            abortButton = msg.addButton(self.tr("Abort"), QMessageBox.ButtonRole.RejectRole)
+            msg.addButton(self.tr("Continue"), QMessageBox.ButtonRole.AcceptRole)
             msg.setDefaultButton(abortButton)
             msg.setText(self.tr(f"The repository at {repo_url} might be in use elsewhere."))
-            msg.setInformativeText(self.tr("Only break the lock if you are certain no other Borg process "
-                                           "on any machine is accessing the repository. Abort or break the lock?"))
+            msg.setInformativeText(
+                self.tr(
+                    "Only break the lock if you are certain no other Borg process "
+                    "on any machine is accessing the repository. Abort or break the lock?"
+                )
+            )
             msg.accepted.connect(lambda: self.break_lock(profile))
             self._msg = msg
             msg.show()
@@ -243,7 +244,9 @@ class VortaApp(QtSingleApplication):
             msg = QMessageBox()
             msg.setText(
                 self.tr(
-                    f"You do not have permission to access the repository at {repo_url}. Gain access and try again."))  # noqa: E501
+                    f"You do not have permission to access the repository at {repo_url}. Gain access and try again."
+                )
+            )  # noqa: E501
             msg.setWindowTitle(self.tr("No Repository Permissions"))
             self._msg = msg
             msg.show()
@@ -251,7 +254,7 @@ class VortaApp(QtSingleApplication):
     def break_lock(self, profile):
         params = BorgBreakJob.prepare(profile)
         if not params['ok']:
-            self.backup_progress_event.emit(params['message'])
+            self.backup_progress_event.emit(f"[{profile.name}] {params['message']}")
             return
         job = BorgBreakJob(params['cmd'], params)
         self.jobs_manager.add_job(job)
@@ -268,22 +271,25 @@ class VortaApp(QtSingleApplication):
                 profile = profile_export.to_db(overwrite_profile=True, overwrite_settings=True)
             except Exception as exception:
                 double_newline = os.linesep + os.linesep
-                QMessageBox.critical(None,
-                                     self.tr('Failed to import profile'),
-                                     "{}{}\"{}\"{}{}".format(
-                                         self.tr('Failed to import a profile from {}:').format(bootstrap_file),
-                                         double_newline,
-                                         str(exception),
-                                         double_newline,
-                                         self.tr('Consider removing or repairing this file to '
-                                                 'get rid of this message.'),
-                                     ))
+                QMessageBox.critical(
+                    None,
+                    self.tr('Failed to import profile'),
+                    "{}{}\"{}\"{}{}".format(
+                        self.tr('Failed to import a profile from {}:').format(bootstrap_file),
+                        double_newline,
+                        str(exception),
+                        double_newline,
+                        self.tr('Consider removing or repairing this file to ' 'get rid of this message.'),
+                    ),
+                )
                 return
             bootstrap_file.unlink()
             notifier = VortaNotifications.pick()
-            notifier.deliver(self.tr('Profile import successful!'),
-                             self.tr('Profile {} imported.').format(profile.name),
-                             level='info')
+            notifier.deliver(
+                self.tr('Profile import successful!'),
+                self.tr('Profile {} imported.').format(profile.name),
+                level='info',
+            )
             logger.info('Profile {} imported.'.format(profile.name))
         if BackupProfileModel.select().count() == 0:
             default_profile = BackupProfileModel(name='Default')
@@ -310,8 +316,7 @@ class VortaApp(QtSingleApplication):
         # Switch over returncodes
         if returncode == 0:
             # No fail
-            logger.warning(
-                'VortaApp.check_failed_response was called with returncode 0')
+            logger.warning('VortaApp.check_failed_response was called with returncode 0')
         elif returncode == 130:
             # Keyboard interupt
             pass
@@ -319,27 +324,26 @@ class VortaApp(QtSingleApplication):
             # Create QMessageBox
             msg = QMessageBox()
             msg.setIcon(QMessageBox.Icon.Critical)  # changed for warning
-            msg.setStandardButtons(QMessageBox.Ok)
+            msg.setStandardButtons(QMessageBox.StandardButton.Ok)
             msg.setWindowTitle(self.tr('Repo Check Failed'))
 
             if returncode == 1:
                 # warning
                 msg.setIcon(QMessageBox.Icon.Warning)
-                text = self.tr('Borg exited with a warning message. See logs for details.')
+                text = translate(
+                    'VortaApp', 'Borg exited with warning status (rc 1). See the <a href="{0}">logs</a> for details.'
+                ).format(LOG_DIR.as_uri())
                 infotext = error_message
             elif returncode > 128:
                 # 128+N - killed by signal N (e.g. 137 == kill -9)
                 signal = returncode - 128
-                text = (
-                    self.tr('Repository data check for repo was killed by signal %s.')
-                    % (signal)
-                )
+                text = self.tr('Repository data check for repo was killed by signal %s.') % (signal)
                 infotext = self.tr('The process running the check job got a kill signal. Try again.')
             else:
                 # Real error
-                text = (
-                    self.tr('Repository data check for repo %s failed. Error code %s')
-                    % (repo_url, returncode)
+                text = self.tr('Repository data check for repo %s failed. Error code %s') % (
+                    repo_url,
+                    returncode,
                 )
                 infotext = error_message + '\n'
                 infotext += self.tr('Consider repairing or recreating the repository soon to avoid missing data.')
