@@ -6,7 +6,6 @@ Set up logging to user log dir. Uses the platform's default location:
 
 """
 
-import os
 import logging
 from logging.handlers import TimedRotatingFileHandler
 from .config import LOG_DIR
@@ -17,16 +16,13 @@ logger = logging.getLogger()
 def init_logger(background=False):
     logger.setLevel(logging.DEBUG)
     logging.getLogger('peewee').setLevel(logging.INFO)
-    logging.getLogger('PyQt5').setLevel(logging.INFO)
+    logging.getLogger('PyQt6').setLevel(logging.INFO)
 
     # create logging format
     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
     # create handlers
-    fh = TimedRotatingFileHandler(os.path.join(LOG_DIR, 'vorta.log'),
-                                  when='d',
-                                  interval=1,
-                                  backupCount=5)
+    fh = TimedRotatingFileHandler(LOG_DIR / 'vorta.log', when='d', interval=1, backupCount=5)
     fh.setLevel(logging.DEBUG)
     fh.setFormatter(formatter)
     logger.addHandler(fh)
