@@ -1,6 +1,6 @@
-import sys
 import logging
-from PyQt5 import QtCore, QtDBus
+import sys
+from PyQt6 import QtCore, QtDBus
 from vorta.store.models import SettingsModel
 
 logger = logging.getLogger(__name__)
@@ -13,6 +13,7 @@ class VortaNotifications:
     notifier = Notifications.pick()()
     notifier.deliver('blah', 'blah blah')
     """
+
     @classmethod
     def pick(cls):
         if sys.platform == 'darwin':
@@ -24,7 +25,7 @@ class VortaNotifications:
             return cls()
 
     def deliver(self, title, text, level='info'):
-        """Dummy notifier if we're not on macOS or Linux notifier isn't available."""
+        """Dummy notifier if we're not on macOS or Linux notifier is not available."""
         pass
 
     def notifications_suppressed(self, level):
@@ -50,6 +51,7 @@ class DarwinNotifications(VortaNotifications):
             return
 
         from Foundation import NSUserNotification, NSUserNotificationCenter
+
         notification = NSUserNotification.alloc().init()
         notification.setTitle_(title)
         notification.setInformativeText_(text)
@@ -75,22 +77,32 @@ class DBusNotifications(VortaNotifications):
         path = "/org/freedesktop/Notifications"
         interface = "org.freedesktop.Notifications"
         app_name = "vorta"
-        v = QtCore.QVariant(12321)  # random int to identify all notifications
-        if v.convert(QtCore.QVariant.UInt):
-            id_replace = v
+        id_replace = QtCore.QVariant(12321)
+        id_replace.convert(QtCore.QMetaType(QtCore.QMetaType.Type.UInt.value))
         icon = "com.borgbase.Vorta-symbolic"
         title = header
         text = msg
-        actions_list = QtDBus.QDBusArgument([], QtCore.QMetaType.QStringList)
+        actions_list = QtDBus.QDBusArgument([], QtCore.QMetaType.Type.QStringList.value)
         hint = {'urgency': self.URGENCY[level]}
-        time = 5000   # milliseconds for display timeout
+        time = 5000  # milliseconds for display timeout
 
         bus = QtDBus.QDBusConnection.sessionBus()
         notify = QtDBus.QDBusInterface(item, path, interface, bus)
         if notify.isValid():
-            x = notify.call(QtDBus.QDBus.AutoDetect, "Notify", app_name,
-                            id_replace, icon, title, text,
-                            actions_list, hint, time)
+            x = notify.call(
+                # Call arguments for Notify interface need to match exactly:
+                # https://specifications.freedesktop.org/notification-spec/notification-spec-latest.html#command-notify
+                QtDBus.QDBus.CallMode.AutoDetect,
+                "Notify",
+                app_name,
+                id_replace,
+                icon,
+                title,
+                text,
+                actions_list,
+                hint,
+                time,
+            )
             if x.errorName():
                 logger.warning("Failed to send notification!")
                 logger.warning(x.errorMessage())
