@@ -1,24 +1,25 @@
 import os
-from PyQt5.QtWidgets import QMenu, QSystemTrayIcon
-from PyQt5.QtGui import QIcon
-
+from PyQt6.QtGui import QIcon
+from PyQt6.QtWidgets import QApplication, QMenu, QSystemTrayIcon
 from vorta.store.models import BackupProfileModel
 from vorta.utils import get_asset
 
 
 class TrayMenu(QSystemTrayIcon):
-    def __init__(self, parent=None):
+    def __init__(self, parent: QApplication = None):
         QSystemTrayIcon.__init__(self, parent)
         self.app = parent
         self.set_tray_icon()
         menu = QMenu()
 
         # Workaround to get `activated` signal on Unity: https://stackoverflow.com/a/43683895/3983708
-        menu.aboutToShow.connect(self.on_user_click)
+        menu.aboutToShow.connect(self.build_menu)
 
         self.setContextMenu(menu)
+        self.build_menu()
 
         self.activated.connect(self.on_activation)
+        self.app.paletteChanged.connect(lambda p: self.set_tray_icon())
         self.setVisible(True)
         self.show()
 
@@ -29,11 +30,13 @@ class TrayMenu(QSystemTrayIcon):
 
         If XDG_CURRENT_DESKTOP isn't set, always open the tray menu (macOS)
         """
-        if reason in [QSystemTrayIcon.Trigger, QSystemTrayIcon.DoubleClick] and \
-                os.environ.get('XDG_CURRENT_DESKTOP'):
+        if reason in [
+            QSystemTrayIcon.ActivationReason.Trigger,
+            QSystemTrayIcon.ActivationReason.DoubleClick,
+        ] and os.environ.get('XDG_CURRENT_DESKTOP'):
             self.app.toggle_main_window_visibility()
 
-    def on_user_click(self):
+    def build_menu(self):
         """Build system tray menu based on current state."""
 
         menu = self.contextMenu()
