@@ -1,16 +1,22 @@
 import logging
-import os.path
 import sys
 from datetime import timedelta
 from typing import Dict, Optional
-
-from PyQt5 import QtCore, uic
-from PyQt5.QtCore import QItemSelectionModel, QMimeData, QPoint, Qt, pyqtSlot
-from PyQt5.QtGui import QDesktopServices, QKeySequence
-from PyQt5.QtWidgets import (QAction, QApplication, QHeaderView, QInputDialog,
-                             QLayout, QMenu, QMessageBox, QShortcut,
-                             QTableView, QTableWidgetItem, QWidget)
-
+from PyQt6 import QtCore, uic
+from PyQt6.QtCore import QItemSelectionModel, QMimeData, QPoint, Qt, pyqtSlot
+from PyQt6.QtGui import QAction, QDesktopServices, QKeySequence, QShortcut
+from PyQt6.QtWidgets import (
+    QAbstractItemView,
+    QApplication,
+    QHeaderView,
+    QInputDialog,
+    QLayout,
+    QMenu,
+    QMessageBox,
+    QTableView,
+    QTableWidgetItem,
+    QWidget,
+)
 from vorta.borg.check import BorgCheckJob
 from vorta.borg.compact import BorgCompactJob
 from vorta.borg.delete import BorgDeleteJob
@@ -23,11 +29,19 @@ from vorta.borg.mount import BorgMountJob
 from vorta.borg.prune import BorgPruneJob
 from vorta.borg.rename import BorgRenameJob
 from vorta.borg.umount import BorgUmountJob
+from vorta.i18n import translate
 from vorta.store.models import ArchiveModel, BackupProfileMixin
-from vorta.utils import (choose_file_dialog, format_archive_name, get_asset,
-                         get_mount_points, pretty_bytes)
-from vorta.views.diff_result import DiffResult
-from vorta.views.extract_dialog import ExtractDialog
+from vorta.utils import (
+    choose_file_dialog,
+    find_best_unit_for_sizes,
+    format_archive_name,
+    get_asset,
+    get_mount_points,
+    pretty_bytes,
+)
+from vorta.views import diff_result, extract_dialog
+from vorta.views.diff_result import DiffResultDialog, DiffTree
+from vorta.views.extract_dialog import ExtractDialog, ExtractTree
 from vorta.views.source_tab import SizeItem
 from vorta.views.utils import get_colored_icon
 
@@ -37,6 +51,10 @@ ArchiveTabUI, ArchiveTabBase = uic.loadUiType(uifile)
 logger = logging.getLogger(__name__)
 
 
+#: The number of decimal digits to show in the size column
+SIZE_DECIMAL_DIGITS = 1
+
+
 class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
     prune_intervals = ['hour', 'day', 'week', 'month', 'year']
 
@@ -44,9 +62,8 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         """Init."""
         super().__init__(parent)
         self.setupUi(parent)
-        self.mount_points = {}  # mount points of archives
-        self.repo_mount_point: Optional[
-            str] = None  # mount point of whole repo
+        self.mount_points = {}  # mapping of archive name to mount point
+        self.repo_mount_point: Optional[str] = None  # mount point of whole repo
         self.menu = None
         self.app = app
         self.toolBox.setCurrentIndex(0)
@@ -59,38 +76,33 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
         header = self.archiveTable.horizontalHeader()
         header.setVisible(True)
-        header.setSectionResizeMode(0, QHeaderView.ResizeToContents)
-        header.setSectionResizeMode(1, QHeaderView.ResizeToContents)
-        header.setSectionResizeMode(2, QHeaderView.ResizeToContents)
-        header.setSectionResizeMode(3, QHeaderView.Interactive)
-        header.setSectionResizeMode(4, QHeaderView.Stretch)
+        header.setSectionResizeMode(0, QHeaderView.ResizeMode.ResizeToContents)
+        header.setSectionResizeMode(1, QHeaderView.ResizeMode.ResizeToContents)
+        header.setSectionResizeMode(2, QHeaderView.ResizeMode.ResizeToContents)
+        header.setSectionResizeMode(3, QHeaderView.ResizeMode.Interactive)
+        header.setSectionResizeMode(4, QHeaderView.ResizeMode.Stretch)
         header.setStretchLastSection(True)
 
         if sys.platform != 'darwin':
             self._set_status('')  # Set platform-specific hints.
 
-        self.archiveTable.setSelectionBehavior(QTableView.SelectRows)
-        self.archiveTable.setEditTriggers(QTableView.NoEditTriggers)
+        self.archiveTable.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
+        self.archiveTable.setEditTriggers(QAbstractItemView.EditTrigger.NoEditTriggers)
         self.archiveTable.setWordWrap(False)
-        self.archiveTable.setTextElideMode(QtCore.Qt.ElideLeft)
+        self.archiveTable.setTextElideMode(QtCore.Qt.TextElideMode.ElideLeft)
         self.archiveTable.setAlternatingRowColors(True)
         self.archiveTable.cellDoubleClicked.connect(self.cell_double_clicked)
         self.archiveTable.setSortingEnabled(True)
-        self.archiveTable.setContextMenuPolicy(
-            Qt.ContextMenuPolicy.CustomContextMenu)
-        self.archiveTable.customContextMenuRequested.connect(
-            self.archiveitem_contextmenu)
+        self.archiveTable.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        self.archiveTable.customContextMenuRequested.connect(self.archiveitem_contextmenu)
 
         # shortcuts
-        shortcut_copy = QShortcut(QKeySequence.StandardKey.Copy,
-                                  self.archiveTable)
+        shortcut_copy = QShortcut(QKeySequence.StandardKey.Copy, self.archiveTable)
         shortcut_copy.activated.connect(self.archive_copy)
 
         # single and double selection feature
-        self.archiveTable.setSelectionMode(
-            QTableView.SelectionMode.ExtendedSelection)
-        self.archiveTable.selectionModel().selectionChanged.connect(
-            self.on_selection_change)
+        self.archiveTable.setSelectionMode(QTableView.SelectionMode.ExtendedSelection)
+        self.archiveTable.selectionModel().selectionChanged.connect(self.on_selection_change)
 
         # connect archive actions
         self.bMountArchive.clicked.connect(self.bmountarchive_clicked)
@@ -108,16 +120,19 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         self.bMountRepo.clicked.connect(self.bmountrepo_clicked)
 
         self.archiveNameTemplate.textChanged.connect(
-            lambda tpl, key='new_archive_name': self.save_archive_template(
-                tpl, key))
+            lambda tpl, key='new_archive_name': self.save_archive_template(tpl, key)
+        )
         self.prunePrefixTemplate.textChanged.connect(
-            lambda tpl, key='prune_prefix': self.save_archive_template(
-                tpl, key))
+            lambda tpl, key='prune_prefix': self.save_archive_template(tpl, key)
+        )
 
         self.populate_from_profile()
-        self.selected_archives = None
+        self.selected_archives = None  # TODO: remove unused variable
         self.set_icons()
 
+        # Connect to palette change
+        self.app.paletteChanged.connect(lambda p: self.set_icons())
+
     def set_icons(self):
         "Used when changing between light- and dark mode"
         self.bCheck.setIcon(get_colored_icon('check-circle'))
@@ -132,7 +147,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         self.bDelete.setIcon(get_colored_icon('trash'))
         self.bExtract.setIcon(get_colored_icon('cloud-download'))
 
-        self.bmountarchive_refresh()
+        self.bmountarchive_refresh(icon_only=True)
         self.bmountrepo_refresh()
 
     @pyqtSlot(QPoint)
@@ -142,35 +157,39 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         if not index.isValid():
             return  # popup only for items
 
-        selected_rows = self.archiveTable.selectionModel().selectedRows(
-            index.column())
+        selected_rows = self.archiveTable.selectionModel().selectedRows(index.column())
 
         if selected_rows and index not in selected_rows:
             return  # popup only for selected items
 
         menu = QMenu(self.archiveTable)
-        menu.addAction(get_colored_icon('copy'), self.tr("Copy"),
-                       lambda: self.archive_copy(index=index))
+        menu.addAction(
+            get_colored_icon('copy'),
+            self.tr("Copy"),
+            lambda: self.archive_copy(index=index),
+        )
         menu.addSeparator()
 
         # archive actions
         archive_actions = []
         archive_actions.append(
-            menu.addAction(self.bRefreshArchive.icon(),
-                           self.bRefreshArchive.text(),
-                           self.refresh_archive_info))
+            menu.addAction(
+                self.bRefreshArchive.icon(),
+                self.bRefreshArchive.text(),
+                self.refresh_archive_info,
+            )
+        )
         archive_actions.append(
-            menu.addAction(self.bMountArchive.icon(), self.bMountArchive.text(),
-                           self.bmountarchive_clicked))
-        archive_actions.append(
-            menu.addAction(self.bExtract.icon(), self.bExtract.text(),
-                           self.extract_action))
-        archive_actions.append(
-            menu.addAction(self.bRename.icon(), self.bRename.text(),
-                           self.rename_action))
+            menu.addAction(
+                self.bMountArchive.icon(),
+                self.bMountArchive.text(),
+                self.bmountarchive_clicked,
+            )
+        )
+        archive_actions.append(menu.addAction(self.bExtract.icon(), self.bExtract.text(), self.extract_action))
+        archive_actions.append(menu.addAction(self.bRename.icon(), self.bRename.text(), self.rename_action))
         # deletion possible with one but also multiple archives
-        menu.addAction(self.bDelete.icon(), self.bDelete.text(),
-                       self.delete_action)
+        menu.addAction(self.bDelete.icon(), self.bDelete.text(), self.delete_action)
 
         if not (self.repoactions_enabled and len(selected_rows) <= 1):
             for action in archive_actions:
@@ -182,10 +201,8 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         diff_action.triggered.connect(self.diff_action)
         menu.addAction(diff_action)
 
-        selected_rows = self.archiveTable.selectionModel().selectedRows(
-            index.column())
-        diff_action.setEnabled(self.repoactions_enabled
-                               and len(selected_rows) == 2)
+        selected_rows = self.archiveTable.selectionModel().selectedRows(index.column())
+        diff_action.setEnabled(self.repoactions_enabled and len(selected_rows) == 2)
 
         menu.popup(self.archiveTable.viewport().mapToGlobal(pos))
 
@@ -208,8 +225,16 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         """
         self.repoactions_enabled = enabled
 
-        for button in [self.bCheck, self.bList, self.bPrune,
-                       self.bDiff, self.fArchiveActions, self.bMountRepo]:
+        for button in [
+            self.bCheck,
+            self.bList,
+            self.bPrune,
+            self.bDiff,
+            self.bMountRepo,
+            self.bDelete,
+            self.compactButton,
+            self.fArchiveActions,
+        ]:
             button.setEnabled(enabled)
             button.repaint()
 
@@ -230,12 +255,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             sorting = self.archiveTable.isSortingEnabled()
             self.archiveTable.setSortingEnabled(False)
+            best_unit = find_best_unit_for_sizes((a.size for a in archives), precision=SIZE_DECIMAL_DIGITS)
             for row, archive in enumerate(archives):
                 self.archiveTable.insertRow(row)
 
                 formatted_time = archive.time.strftime('%Y-%m-%d %H:%M')
                 self.archiveTable.setItem(row, 0, QTableWidgetItem(formatted_time))
-                self.archiveTable.setItem(row, 1, SizeItem(pretty_bytes(archive.size)))
+                self.archiveTable.setItem(
+                    row, 1, SizeItem(pretty_bytes(archive.size, fixed_unit=best_unit, precision=SIZE_DECIMAL_DIGITS))
+                )
                 if archive.duration is not None:
                     formatted_duration = str(timedelta(seconds=round(archive.duration)))
                 else:
@@ -289,25 +317,28 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             The previous selection.
         """
         # handle selection of more than 2 rows
-        selectionModel: QItemSelectionModel = self.archiveTable.selectionModel(
-        )
+        selectionModel: QItemSelectionModel = self.archiveTable.selectionModel()
         indexes = selectionModel.selectedRows()
 
         # Toggle archive actions frame
         layout: QLayout = self.fArchiveActions.layout()
 
+        # task in progress -> disable all
+        reason = ""
+        if not self.repoactions_enabled:
+            reason = self.tr("(borg already running)")
+
         # toggle delete button
-        if len(indexes) > 0:
+        if self.repoactions_enabled and len(indexes) > 0:
             self.bDelete.setEnabled(True)
             self.bDelete.setToolTip(self.tooltip_dict.get(self.bDelete, ""))
         else:
             self.bDelete.setEnabled(False)
             tooltip = self.tooltip_dict[self.bDelete]
-            self.bDelete.setToolTip(tooltip + " " +
-                                    self.tr("(Select two archives)"))
+            self.bDelete.setToolTip(tooltip + " " + reason or self.tr("(Select minimum one archive)"))
 
         # Toggle diff button
-        if len(indexes) == 2:
+        if self.repoactions_enabled and len(indexes) == 2:
             # Enable diff button
             self.bDiff.setEnabled(True)
             self.bDiff.setToolTip(self.tooltip_dict.get(self.bDiff, ""))
@@ -316,10 +347,9 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self.bDiff.setEnabled(False)
 
             tooltip = self.tooltip_dict[self.bDiff]
-            self.bDiff.setToolTip(tooltip + " " +
-                                  self.tr("(Select two archives)"))
+            self.bDiff.setToolTip(tooltip + " " + reason or self.tr("(Select two archives)"))
 
-        if len(indexes) == 1:
+        if self.repoactions_enabled and len(indexes) == 1:
             # Enable archive actions
             self.fArchiveActions.setEnabled(True)
 
@@ -330,6 +360,8 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             # refresh bMountArchive for the selected archive
             self.bmountarchive_refresh()
         else:
+            reason = reason or self.tr("(Select exactly one archive)")
+
             # too few or too many selected.
             self.fArchiveActions.setEnabled(False)
 
@@ -338,8 +370,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 tooltip = widget.toolTip()
 
                 tooltip = self.tooltip_dict.setdefault(widget, tooltip)
-                widget.setToolTip(tooltip + " " +
-                                  self.tr("(Select exactly one archive)"))
+                widget.setToolTip(tooltip + " " + reason)
+
+            # special treatment for dynamic mount/unmount button.
+            self.bmountarchive_refresh()
+            tooltip = self.bMountArchive.toolTip()
+            self.bMountArchive.setToolTip(tooltip + " " + reason)
 
     def archive_copy(self, index=None):
         """
@@ -502,7 +538,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         else:
             self.mount_action()
 
-    def bmountarchive_refresh(self):
+    def bmountarchive_refresh(self, icon_only=False):
         """
         Update label, tooltip and state of `bMountArchive`.
 
@@ -512,16 +548,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         archive_name = self.selected_archive_name()
 
         if archive_name in self.mount_points:
-            self.bMountArchive.setText(self.tr("Unmount"))
             self.bMountArchive.setIcon(get_colored_icon('eject'))
-            self.bMountArchive.setToolTip(
-                self.tr('Unmount the selected archive from the file system.'))
+            if not icon_only:
+                self.bMountArchive.setText(self.tr("Unmount"))
+                self.bMountArchive.setToolTip(self.tr('Unmount the selected archive from the file system'))
         else:
-            self.bMountArchive.setText(self.tr("Mount…"))
             self.bMountArchive.setIcon(get_colored_icon('folder-open'))
-            self.bMountRepo.setToolTip(
-                self.tr("Mount the selected archive " +
-                        "as a folder in the file system."))
+            if not icon_only:
+                self.bMountArchive.setText(self.tr("Mount…"))
+                self.bMountArchive.setToolTip(self.tr("Mount the selected archive " + "as a folder in the file system"))
 
     def bmountrepo_refresh(self):
         """
@@ -532,14 +567,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         """
         if self.repo_mount_point:
             self.bMountRepo.setText(self.tr("Unmount"))
-            self.bMountRepo.setToolTip(
-                self.tr('Unmount the repository from the file system.'))
+            self.bMountRepo.setToolTip(self.tr('Unmount the repository from the file system'))
             self.bMountRepo.setIcon(get_colored_icon('eject'))
         else:
             self.bMountRepo.setText(self.tr("Mount…"))
             self.bMountRepo.setIcon(get_colored_icon('folder-open'))
-            self.bMountRepo.setToolTip(
-                self.tr("Mount the repository as a folder in the file system."))
+            self.bMountRepo.setToolTip(self.tr("Mount the repository as a folder in the file system"))
 
     def mount_action(self, archive_name=None):
         """
@@ -554,17 +587,11 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             The archive to mount or None, by default None
         """
         profile = self.profile()
-        params = BorgMountJob.prepare(profile)
+        params = BorgMountJob.prepare(profile, archive=archive_name)
         if not params['ok']:
             self._set_status(params['message'])
             return
 
-        if archive_name:
-            # mount archive
-            params['cmd'][-1] += f'::{archive_name}'
-            params['current_archive'] = archive_name
-        # else mount complete repo
-
         def receive():
             mount_point = dialog.selectedFiles()
             if mount_point:
@@ -587,13 +614,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             mount_point = result['params']['mount_point']
 
-            if result['params'].get('current_archive'):
+            if result['params'].get('mounted_archive'):
                 # archive was mounted
-                archive_name = result['params']['current_archive']
+                archive_name = result['params']['mounted_archive']
                 self.mount_points[archive_name] = mount_point
 
                 # update column in table
-                archive_name = result['params']['current_archive']
                 row = self.row_of_archive(archive_name)
                 item = QTableWidgetItem(result['cmd'][-1])
                 self.archiveTable.setItem(row, 3, item)
@@ -627,25 +653,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
         if mount_point is not None:
             profile = self.profile()
-            params = BorgUmountJob.prepare(profile)
+            params = BorgUmountJob.prepare(profile, mount_point, archive_name=archive_name)
             if not params['ok']:
-                self._set_status(params['message'])
+                self._set_status(translate('message', params['message']))
                 return
 
-            if archive_name:
-                params['current_archive'] = archive_name
-            params['mount_point'] = mount_point
-
-            if os.path.normpath(mount_point) in params['active_mount_points']:
-                params['cmd'].append(mount_point)
-
-                job = BorgUmountJob(params['cmd'], params, self.profile().repo.id)
-                job.updated.connect(self.mountErrors.setText)
-                job.result.connect(self.umount_result)
-                self.app.jobs_manager.add_job(job)
-            else:
-                self._set_status(self.tr('Mount point not active.'))
-                return
+            job = BorgUmountJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self.mountErrors.setText)
+            job.result.connect(self.umount_result)
+            self.app.jobs_manager.add_job(job)
 
     def umount_result(self, result):
         self._toggle_all_buttons(True)
@@ -670,9 +686,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
                 self.bmountrepo_refresh()
         else:
-            self._set_status(
-                self.tr('Unmounting failed. Make sure no programs are using {}')
-                .format(mount_point))
+            self._set_status(self.tr('Unmounting failed. Make sure no programs are using {}').format(mount_point))
 
     def save_prune_setting(self, new_value=None):
         profile = self.profile()
@@ -682,6 +696,9 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         profile.save()
 
     def extract_action(self):
+        """
+        Open a dialog for choosing what to extract from the selected archive.
+        """
         profile = self.profile()
 
         row_selected = self.archiveTable.selectionModel().selectedRows()
@@ -706,35 +723,46 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self._set_status(self.tr('Select an archive to restore first.'))
 
     def extract_list_result(self, result):
+        """Process the contents of the archive to extract."""
         self._set_status('')
         if result['returncode'] == 0:
-            def process_result():
-                def receive():
-                    extraction_folder = dialog.selectedFiles()
-                    if extraction_folder:
-                        params = BorgExtractJob.prepare(
-                            self.profile(), archive.name, window.selected, extraction_folder[0])
-                        if params['ok']:
-                            self._toggle_all_buttons(False)
-                            job = BorgExtractJob(params['cmd'], params, self.profile().repo.id)
-                            job.updated.connect(self.mountErrors.setText)
-                            job.result.connect(self.extract_archive_result)
-                            self.app.jobs_manager.add_job(job)
-                        else:
-                            self._set_status(params['message'])
-
-                dialog = choose_file_dialog(self, self.tr("Choose Extraction Point"), want_folder=True)
-                dialog.open(receive)
-
             archive = ArchiveModel.get(name=result['params']['archive_name'])
-            window = ExtractDialog(result['data'], archive)
-            self._toggle_all_buttons(True)
-            window.setParent(self, QtCore.Qt.Sheet)
-            self._window = window  # for testing
-            window.show()
-            window.accepted.connect(process_result)
+            model = ExtractTree()
+            self._set_status(self.tr("Processing archive contents"))
+            self._t = extract_dialog.ParseThread(result['data'], model)
+            self._t.finished.connect(lambda: self.extract_show_dialog(archive, model))
+            self._t.start()
+
+    def extract_show_dialog(self, archive, model):
+        """Show the dialog for choosing the archive contents to extract."""
+        self._set_status('')
+
+        def process_result():
+            def receive():
+                extraction_folder = dialog.selectedFiles()
+                if extraction_folder:
+                    params = BorgExtractJob.prepare(self.profile(), archive.name, model, extraction_folder[0])
+                    if params['ok']:
+                        self._toggle_all_buttons(False)
+                        job = BorgExtractJob(params['cmd'], params, self.profile().repo.id)
+                        job.updated.connect(self.mountErrors.setText)
+                        job.result.connect(self.extract_archive_result)
+                        self.app.jobs_manager.add_job(job)
+                    else:
+                        self._set_status(params['message'])
+
+            dialog = choose_file_dialog(self, self.tr("Choose Extraction Point"), want_folder=True)
+            dialog.open(receive)
+
+        window = ExtractDialog(archive, model)
+        self._toggle_all_buttons(True)
+        window.setParent(self, QtCore.Qt.WindowType.Sheet)
+        self._window = window  # for testing
+        window.show()
+        window.accepted.connect(process_result)
 
     def extract_archive_result(self, result):
+        """Finished extraction."""
         self._toggle_all_buttons(True)
 
     def cell_double_clicked(self, row, column):
@@ -749,19 +777,19 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 QDesktopServices.openUrl(QtCore.QUrl(f'file:///{mount_point}'))
 
     def row_of_archive(self, archive_name):
-        items = self.archiveTable.findItems(archive_name, QtCore.Qt.MatchExactly)
+        items = self.archiveTable.findItems(archive_name, QtCore.Qt.MatchFlag.MatchExactly)
         rows = [item.row() for item in items if item.column() == 4]
         return rows[0] if rows else None
 
     def confirm_dialog(self, title, text):
         msg = QMessageBox()
-        msg.setIcon(QMessageBox.Information)
+        msg.setIcon(QMessageBox.Icon.Information)
         msg.setText(text)
         msg.setWindowTitle(title)
-        msg.setStandardButtons(QMessageBox.Yes | QMessageBox.Cancel)
-        msg.button(msg.Yes).setText(self.tr("Yes"))
-        msg.button(msg.Cancel).setText(self.tr("Cancel"))
-        return msg.exec_() == QMessageBox.Yes
+        msg.setStandardButtons(QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.Cancel)
+        msg.button(QMessageBox.StandardButton.Yes).setText(self.tr("Yes"))
+        msg.button(QMessageBox.StandardButton.Cancel).setText(self.tr("Cancel"))
+        return msg.exec() == QMessageBox.StandardButton.Yes
 
     def delete_action(self):
         # Since this function modify the UI, we can't put the whole function in a JobQUeue.
@@ -806,7 +834,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             # remove rows from list and database
             for archive in archives:
-                for entry in self.archiveTable.findItems(archive, QtCore.Qt.MatchExactly):
+                for entry in self.archiveTable.findItems(archive, QtCore.Qt.MatchFlag.MatchExactly):
                     self.archiveTable.removeRow(entry.row())
                 ArchiveModel.get(name=archive).delete_instance()
 
@@ -825,16 +853,17 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         name1 = self.archiveTable.item(selected_archives[0].row(), 4).text()
         name2 = self.archiveTable.item(selected_archives[1].row(), 4).text()
 
-        archive1, archive2 = (profile.repo.archives.select().where(
-            (ArchiveModel.name == name1)
-            | (ArchiveModel.name == name2)).order_by(ArchiveModel.time.desc()))
+        archive1, archive2 = (
+            profile.repo.archives.select()
+            .where((ArchiveModel.name == name1) | (ArchiveModel.name == name2))
+            .order_by(ArchiveModel.time.desc())
+        )
 
         archive_name_newer = archive1.name
         archive_name_older = archive2.name
 
         # Start diff job
-        params = BorgDiffJob.prepare(profile, archive_name_older,
-                                     archive_name_newer)
+        params = BorgDiffJob.prepare(profile, archive_name_older, archive_name_newer)
 
         if params['ok']:
             self._toggle_all_buttons(False)
@@ -858,23 +887,31 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         """
         self._set_status('')
         if result['returncode'] == 0:
-            archive_newer = ArchiveModel.get(
-                name=result['params']['archive_name_newer'])
-            archive_older = ArchiveModel.get(
-                name=result['params']['archive_name_older'])
-            window = DiffResult(result['data'], archive_newer, archive_older,
-                                result['params']['json_lines'])
-            self._toggle_all_buttons(True)
-            window.setParent(self, QtCore.Qt.Sheet)
-            self._resultwindow = window  # for testing
-            window.show()
+            archive_newer = ArchiveModel.get(name=result['params']['archive_name_newer'])
+            archive_older = ArchiveModel.get(name=result['params']['archive_name_older'])
+            self._set_status(self.tr("Processing diff results."))
+
+            model = DiffTree()
+
+            self._t = diff_result.ParseThread(result['data'], result['params']['json_lines'], model)
+            self._t.finished.connect(lambda: self.show_diff_result(archive_newer, archive_older, model))
+            self._t.start()
+
+    def show_diff_result(self, archive_newer, archive_older, model):
+        self._t = None
+
+        # show dialog
+        self._toggle_all_buttons(True)
+        self._set_status('')
+        window = DiffResultDialog(archive_newer, archive_older, model)
+        window.setParent(self)
+        window.setWindowFlags(Qt.WindowType.Window)
+        window.setWindowModality(Qt.WindowModality.NonModal)
+        self._resultwindow = window  # for testing
+        window.show()
 
     def rename_action(self):
         profile = self.profile()
-        params = BorgRenameJob.prepare(profile)
-        if not params['ok']:
-            self._set_status(params['message'])
-            return
 
         archive_name = self.selected_archive_name()
         if archive_name is not None:
@@ -882,7 +919,8 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 self,
                 self.tr("Change name"),
                 self.tr("New archive name:"),
-                text=archive_name)
+                text=archive_name,
+            )
 
             if not finished:
                 return
@@ -896,8 +934,10 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 self._set_status(self.tr('An archive with this name already exists.'))
                 return
 
-            params['cmd'][-1] += f'::{archive_name}'
-            params['cmd'].append(new_name)
+            params = BorgRenameJob.prepare(profile, archive_name, new_name)
+            if not params['ok']:
+                self._set_status(params['message'])
+
             job = BorgRenameJob(params['cmd'], params, self.profile().repo.id)
             job.updated.connect(self._set_status)
             job.result.connect(self.rename_result)
