@@ -1,16 +1,14 @@
-from pathlib import Path
 import logging
-
-from PyQt5 import QtCore, uic
-from PyQt5.QtCore import QPoint
-from PyQt5.QtGui import QKeySequence
-from PyQt5.QtWidgets import QShortcut, QMessageBox, QCheckBox, QMenu, QToolTip, QFileDialog
-
+from pathlib import Path
+from PyQt6 import QtCore, uic
+from PyQt6.QtCore import QPoint
+from PyQt6.QtGui import QFontMetrics, QKeySequence, QShortcut
+from PyQt6.QtWidgets import QApplication, QCheckBox, QFileDialog, QMenu, QMessageBox, QToolTip
+from vorta.profile_export import ImportFailedException, ProfileExport
 from vorta.store.models import BackupProfileModel, SettingsModel
-from vorta.utils import borg_compat, get_asset, is_system_tray_available, get_network_status_monitor
+from vorta.utils import borg_compat, get_asset, get_network_status_monitor, is_system_tray_available
 from vorta.views.partials.loading_button import LoadingButton
 from vorta.views.utils import get_colored_icon
-from vorta.profile_export import ProfileExport, ImportFailedException
 from .archive_tab import ArchiveTab
 from .export_window import ExportWindow
 from .import_window import ImportWindow
@@ -20,10 +18,11 @@ from .repo_tab import RepoTab
 from .schedule_tab import ScheduleTab
 from .source_tab import SourceTab
 
-logger = logging.getLogger(__name__)
 uifile = get_asset('UI/mainwindow.ui')
 MainWindowUI, MainWindowBase = uic.loadUiType(uifile)
 
+logger = logging.getLogger(__name__)
+
 
 class MainWindow(MainWindowBase, MainWindowUI):
     def __init__(self, parent=None):
@@ -32,11 +31,15 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.setWindowTitle('Vorta for Borg Backup')
         self.app = parent
         self.setWindowIcon(get_colored_icon("icon"))
-        self.setWindowFlags(QtCore.Qt.WindowCloseButtonHint | QtCore.Qt.WindowMinimizeButtonHint)
+        self.setWindowFlags(QtCore.Qt.WindowType.WindowCloseButtonHint | QtCore.Qt.WindowType.WindowMinimizeButtonHint)
         self.createStartBtn = LoadingButton(self.tr("Start Backup"))
         self.gridLayout.addWidget(self.createStartBtn, 0, 0, 1, 1)
         self.createStartBtn.setGif(get_asset("icons/loading"))
 
+        # set log label height to two lines
+        fontmetrics: QFontMetrics = self.logText.fontMetrics()
+        self.logText.setMinimumHeight(fontmetrics.lineSpacing() * 2 + fontmetrics.leading())
+
         # Use previous window state
         previous_window_width = SettingsModel.get(key='previous_window_width')
         previous_window_height = SettingsModel.get(key='previous_window_height')
@@ -59,7 +62,7 @@ class MainWindow(MainWindowBase, MainWindowUI):
 
         self.repoTab.repo_changed.connect(self.archiveTab.populate_from_profile)
         self.repoTab.repo_changed.connect(self.scheduleTab.populate_from_profile)
-        self.repoTab.repo_added.connect(self.archiveTab.list_action)
+        self.repoTab.repo_added.connect(self.archiveTab.refresh_archive_list)
 
         self.createStartBtn.clicked.connect(self.app.create_backup_action)
         self.cancelButton.clicked.connect(self.app.backup_cancelled_event.emit)
@@ -80,7 +83,7 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.profileExportButton.clicked.connect(self.profile_export_action)
         self.profileDeleteButton.clicked.connect(self.profile_delete_action)
         profile_add_menu = QMenu()
-        profile_add_menu.addAction(self.tr('Import from file...'), self.profile_import_action)
+        profile_add_menu.addAction(self.tr('Import from file…'), self.profile_import_action)
         self.profileAddButton.setMenu(profile_add_menu)
         self.profileAddButton.clicked.connect(self.profile_add_action)
 
@@ -98,6 +101,9 @@ class MainWindow(MainWindowBase, MainWindowUI):
             self.createStartBtn.start()
             self.cancelButton.setEnabled(True)
 
+        # Connect to palette change
+        QApplication.instance().paletteChanged.connect(lambda p: self.set_icons())
+
         self.set_icons()
 
     def on_close_window(self):
@@ -143,14 +149,14 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.repoTab.populate_from_profile()
         self.sourceTab.populate_from_profile()
         self.scheduleTab.populate_from_profile()
-        SettingsModel.update({SettingsModel.str_value: self.current_profile.id}) \
-            .where(SettingsModel.key == 'previous_profile_id') \
-            .execute()
+        SettingsModel.update({SettingsModel.str_value: self.current_profile.id}).where(
+            SettingsModel.key == 'previous_profile_id'
+        ).execute()
 
     def profile_rename_action(self):
         window = EditProfileWindow(rename_existing_id=self.profileSelector.currentData())
         self.window = window  # For tests
-        window.setParent(self, QtCore.Qt.Sheet)
+        window.setParent(self, QtCore.Qt.WindowType.Sheet)
         window.open()
         window.profile_changed.connect(self.profile_add_edit_result)
         window.rejected.connect(lambda: self.profileSelector.setCurrentIndex(self.profileSelector.currentIndex()))
@@ -161,24 +167,29 @@ class MainWindow(MainWindowBase, MainWindowUI):
             to_delete = BackupProfileModel.get(id=to_delete_id)
 
             msg = self.tr("Are you sure you want to delete profile '{}'?".format(to_delete.name))
-            reply = QMessageBox.question(self, self.tr("Confirm deletion"),
-                                         msg, QMessageBox.Yes | QMessageBox.No, QMessageBox.No)
+            reply = QMessageBox.question(
+                self,
+                self.tr("Confirm deletion"),
+                msg,
+                QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No,
+                QMessageBox.StandardButton.No,
+            )
 
-            if reply == QMessageBox.Yes:
+            if reply == QMessageBox.StandardButton.Yes:
                 to_delete.delete_instance(recursive=True)
                 self.app.scheduler.remove_job(to_delete_id)  # Remove pending jobs
                 self.profileSelector.removeItem(self.profileSelector.currentIndex())
                 self.profile_select_action(0)
 
         else:
-            warn = self.tr("Can't delete the last profile.")
-            point = QPoint(0, self.profileDeleteButton.size().height() / 2)
+            warn = self.tr("Cannot delete the last profile.")
+            point = QPoint(0, int(self.profileDeleteButton.size().height() / 2))
             QToolTip.showText(self.profileDeleteButton.mapToGlobal(point), warn)
 
     def profile_add_action(self):
         window = AddProfileWindow()
         self.window = window  # For tests
-        window.setParent(self, QtCore.Qt.Sheet)
+        window.setParent(self, QtCore.Qt.WindowType.Sheet)
         window.open()
         window.profile_changed.connect(self.profile_add_edit_result)
         window.rejected.connect(lambda: self.profileSelector.setCurrentIndex(self.profileSelector.currentIndex()))
@@ -190,7 +201,7 @@ class MainWindow(MainWindowBase, MainWindowUI):
         """
         window = ExportWindow(profile=self.current_profile.refresh())
         self.window = window
-        window.setParent(self, QtCore.Qt.Sheet)
+        window.setParent(self, QtCore.Qt.WindowType.Sheet)
         window.show()
 
     def profile_import_action(self):
@@ -198,11 +209,14 @@ class MainWindow(MainWindowBase, MainWindowUI):
         React to "Import Profile". Ask to select a .json file and import it as
         new profile.
         """
+
         def profile_imported_event(profile):
-            QMessageBox.information(None,
-                                    self.tr('Profile import successful!'),
-                                    self.tr('Profile {} imported.').format(profile.name))
-            self.repoTab.populate_repositories()
+            QMessageBox.information(
+                None,
+                self.tr('Profile import successful!'),
+                self.tr('Profile {} imported.').format(profile.name),
+            )
+            self.repoTab.populate_from_profile()
             self.scheduleTab.populate_logs()
             self.scheduleTab.populate_wifi()
             self.miscTab.populate()
@@ -212,18 +226,17 @@ class MainWindow(MainWindowBase, MainWindowUI):
             self,
             self.tr("Load profile"),
             str(Path.home()),
-            self.tr("JSON (*.json);;All files (*)"))[0]
+            self.tr("JSON (*.json);;All files (*)"),
+        )[0]
         if filename:
             try:
                 profile_export = ProfileExport.from_json(filename)
             except ImportFailedException as exception:
-                QMessageBox.critical(None,
-                                     self.tr('Failed to import profile'),
-                                     self.tr(str(exception)))
+                QMessageBox.critical(None, self.tr('Failed to import profile'), str(exception))
                 return
             window = ImportWindow(profile_export=profile_export)
             self.window = window
-            window.setParent(self, QtCore.Qt.Sheet)
+            window.setParent(self, QtCore.Qt.WindowType.Sheet)
             window.profile_imported.connect(profile_imported_event)
             window.show()
 
@@ -257,23 +270,28 @@ class MainWindow(MainWindowBase, MainWindowUI):
 
     def closeEvent(self, event):
         # Save window state in SettingsModel
-        SettingsModel.update({SettingsModel.str_value: str(self.width())}) \
-            .where(SettingsModel.key == 'previous_window_width') \
-            .execute()
-        SettingsModel.update({SettingsModel.str_value: str(self.height())}) \
-            .where(SettingsModel.key == 'previous_window_height') \
-            .execute()
+        SettingsModel.update({SettingsModel.str_value: str(self.width())}).where(
+            SettingsModel.key == 'previous_window_width'
+        ).execute()
+        SettingsModel.update({SettingsModel.str_value: str(self.height())}).where(
+            SettingsModel.key == 'previous_window_height'
+        ).execute()
 
         if not is_system_tray_available():
             if SettingsModel.get(key="enable_background_question").value:
                 msg = QMessageBox()
-                msg.setStandardButtons(QMessageBox.Yes | QMessageBox.No)
-                msg.setParent(self, QtCore.Qt.Sheet)
+                msg.setStandardButtons(QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No)
+                msg.setParent(self, QtCore.Qt.WindowType.Sheet)
                 msg.setText(self.tr("Should Vorta continue to run in the background?"))
-                msg.button(QMessageBox.Yes).clicked.connect(
-                    lambda: self.miscTab.save_setting("disable_background_state", True))
-                msg.button(QMessageBox.No).clicked.connect(lambda: (self.miscTab.save_setting(
-                    "disable_background_state", False), self.app.quit()))
+                msg.button(QMessageBox.StandardButton.Yes).clicked.connect(
+                    lambda: self.miscTab.save_setting("disable_background_state", True)
+                )
+                msg.button(QMessageBox.StandardButton.No).clicked.connect(
+                    lambda: (
+                        self.miscTab.save_setting("disable_background_state", False),
+                        self.app.quit(),
+                    )
+                )
                 msg.setWindowTitle(self.tr("Quit"))
                 dont_show_box = QCheckBox(self.tr("Don't show this again"))
                 dont_show_box.clicked.connect(lambda x: self.miscTab.save_setting("enable_background_question", not x))
