@@ -1,15 +1,14 @@
 import re
-from PyQt5 import uic, QtCore
-from PyQt5.QtWidgets import QLineEdit, QAction, QApplication
-
-from vorta.utils import get_private_keys, get_asset, choose_file_dialog, \
-    borg_compat, validate_passwords
-from vorta.keyring.abc import VortaKeyring
-from vorta.borg.init import BorgInitJob
+from PyQt6 import QtCore, uic
+from PyQt6.QtGui import QAction
+from PyQt6.QtWidgets import QApplication, QDialogButtonBox, QLineEdit
 from vorta.borg.info_repo import BorgInfoRepoJob
+from vorta.borg.init import BorgInitJob
 from vorta.i18n import translate
-from vorta.views.utils import get_colored_icon
+from vorta.keyring.abc import VortaKeyring
 from vorta.store.models import RepoModel
+from vorta.utils import borg_compat, choose_file_dialog, get_asset, get_private_keys, validate_passwords
+from vorta.views.utils import get_colored_icon
 
 uifile = get_asset('UI/repoadd.ui')
 AddRepoUI, AddRepoBase = uic.loadUiType(uifile)
@@ -21,12 +20,16 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setupUi(self)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(QtCore.Qt.WidgetAttribute.WA_DeleteOnClose)
         self.result = None
         self.is_remote_repo = True
 
-        self.closeButton.clicked.connect(self.close)
-        self.saveButton.clicked.connect(self.run)
+        # dialogButtonBox
+        self.saveButton = self.buttonBox.button(QDialogButtonBox.StandardButton.Ok)
+        self.saveButton.setText(self.tr("Add"))
+
+        self.buttonBox.rejected.connect(self.close)
+        self.buttonBox.accepted.connect(self.run)
         self.chooseLocalFolderButton.clicked.connect(self.choose_local_backup_folder)
         self.useRemoteRepoButton.clicked.connect(self.use_remote_repo_action)
         self.repoURL.textChanged.connect(self.set_password)
@@ -39,7 +42,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
         self.showHideAction.setCheckable(True)
         self.showHideAction.toggled.connect(self.set_visibility)
 
-        self.passwordLineEdit.addAction(self.showHideAction, QLineEdit.TrailingPosition)
+        self.passwordLineEdit.addAction(self.showHideAction, QLineEdit.ActionPosition.TrailingPosition)
 
         self.tabWidget.setCurrentIndex(0)
 
@@ -48,6 +51,14 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
         self.set_icons()
         self.display_backend_warning()
 
+    def retranslateUi(self, dialog):
+        """Retranslate strings in ui."""
+        super().retranslateUi(dialog)
+
+        # setupUi calls retranslateUi
+        if hasattr(self, 'saveButton'):
+            self.saveButton.setText(self.tr("Add"))
+
     def set_icons(self):
         self.chooseLocalFolderButton.setIcon(get_colored_icon('folder-open'))
         self.useRemoteRepoButton.setIcon(get_colored_icon('globe'))
@@ -59,7 +70,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
             ssh_key=self.sshComboBox.currentData(),
             repo_url=self.repoURL.text(),
             password=self.passwordLineEdit.text(),
-            extra_borg_arguments=self.extraBorgArgumentsLineEdit.text()
+            extra_borg_arguments=self.extraBorgArgumentsLineEdit.text(),
         )
         if self.__class__ == AddRepoWindow:
             out['encryption'] = self.encryptionComboBox.currentData()
@@ -84,7 +95,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
         dialog.open(receive)
 
     def set_password(self, URL):
-        ''' Autofill password from keyring only if current entry is empty '''
+        '''Autofill password from keyring only if current entry is empty'''
         password = VortaKeyring.get_keyring().get_password('vorta-repo', URL)
         if password and self.passwordLineEdit.text() == "":
             self.passwordLabel.setText(self.tr("Autofilled password from password manager."))
@@ -93,7 +104,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
                 self.confirmLineEdit.setText(password)
 
     def set_visibility(self, visible):
-        visibility = QLineEdit.Normal if visible else QLineEdit.Password
+        visibility = QLineEdit.EchoMode.Normal if visible else QLineEdit.EchoMode.Password
         self.passwordLineEdit.setEchoMode(visibility)
         self.confirmLineEdit.setEchoMode(visibility)
 
@@ -138,16 +149,31 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
             self._set_status(self.tr('Unable to add your repository.'))
 
     def init_encryption(self):
-        encryption_algos = [
-            ['Repokey-Blake2 (Recommended, key stored in repository)', 'repokey-blake2'],
-            ['Repokey', 'repokey'],
-            ['Keyfile-Blake2 (Key stored in home directory)', 'keyfile-blake2'],
-            ['Keyfile', 'keyfile'],
-            ['None (not recommended)', 'none']
-        ]
+        if borg_compat.check('V2'):
+            encryption_algos = [
+                [
+                    self.tr('Repokey-ChaCha20-Poly1305 (Recommended, key stored in repository)'),
+                    'repokey-blake2-chacha20-poly1305',
+                ],
+                [
+                    self.tr('Keyfile-ChaCha20-Poly1305 (Key stored in home directory)'),
+                    'keyfile-blake2-chacha20-poly1305',
+                ],
+                [self.tr('Repokey-AES256-OCB'), 'repokey-blake2-aes-ocb'],
+                [self.tr('Keyfile-AES256-OCB'), 'keyfile-blake2-aes-ocb'],
+                [self.tr('None (not recommended)'), 'none'],
+            ]
+        else:
+            encryption_algos = [
+                [self.tr('Repokey-Blake2 (Recommended, key stored in repository)'), 'repokey-blake2'],
+                [self.tr('Repokey'), 'repokey'],
+                [self.tr('Keyfile-Blake2 (Key stored in home directory)'), 'keyfile-blake2'],
+                [self.tr('Keyfile'), 'keyfile'],
+                [self.tr('None (not recommended)'), 'none'],
+            ]
 
         for desc, name in encryption_algos:
-            self.encryptionComboBox.addItem(self.tr(desc), name)
+            self.encryptionComboBox.addItem(desc, name)
 
         if not borg_compat.check('BLAKE2'):
             self.encryptionComboBox.model().item(0).setEnabled(False)
@@ -157,7 +183,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
     def init_ssh_key(self):
         keys = get_private_keys()
         for key in keys:
-            self.sshComboBox.addItem(f'{key["filename"]} ({key["format"]}:{key["fingerprint"]})', key['filename'])
+            self.sshComboBox.addItem(f'{key}', key)
 
     def validate(self):
         """Pre-flight check for valid input and borg binary."""
@@ -172,7 +198,7 @@ class AddRepoWindow(AddRepoBase, AddRepoUI):
         return True
 
     def password_listener(self):
-        ''' Validates passwords only if its going to be used '''
+        '''Validates passwords only if its going to be used'''
         if self.values['encryption'] == 'none':
             self.passwordLabel.setText("")
             return True
@@ -199,7 +225,7 @@ class ExistingRepoWindow(AddRepoWindow):
         del self.confirmLabel
 
     def set_visibility(self, visible):
-        visibility = QLineEdit.Normal if visible else QLineEdit.Password
+        visibility = QLineEdit.EchoMode.Normal if visible else QLineEdit.EchoMode.Password
         self.passwordLineEdit.setEchoMode(visibility)
 
         if visible:
