@@ -1,36 +1,39 @@
 import os
-from PyQt5 import uic
-from PyQt5.QtCore import QProcess, Qt
-from PyQt5.QtWidgets import QApplication
-
-from paramiko.rsakey import RSAKey
-from paramiko.ecdsakey import ECDSAKey
-from paramiko.ed25519key import Ed25519Key
-
+from PyQt6 import uic
+from PyQt6.QtCore import QProcess, Qt
+from PyQt6.QtWidgets import QApplication, QDialogButtonBox
 from ..utils import get_asset
 
 uifile = get_asset('UI/sshadd.ui')
 SSHAddUI, SSHAddBase = uic.loadUiType(uifile)
 
-FORMAT_MAPPING = {
-    'ed25519': Ed25519Key,
-    'rsa': RSAKey,
-    'ecdsa': ECDSAKey
-}
-
 
 class SSHAddWindow(SSHAddBase, SSHAddUI):
     def __init__(self):
         super().__init__()
         self.setupUi(self)
-        self.setAttribute(Qt.WA_DeleteOnClose)
+        self.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
 
-        self.closeButton.clicked.connect(self.accept)
-        self.generateButton.clicked.connect(self.generate_key)
+        # dialogButtonBox
+        self.generateButton = self.buttonBox.button(QDialogButtonBox.StandardButton.Ok)
+
+        self.generateButton.setText(self.tr("Generate and copy to clipboard"))
+
+        # signals
+        self.buttonBox.rejected.connect(self.reject)
+        self.buttonBox.accepted.connect(self.generate_key)
 
         self.init_format()
         self.init_length()
 
+    def retranslateUi(self, dialog):
+        """Retranslate strings in ui."""
+        super().retranslateUi(dialog)
+
+        # setupUi calls retranslateUi
+        if hasattr(self, 'generateButton'):
+            self.generateButton.setText(self.tr("Generate and copy to clipboard"))
+
     def init_format(self):
         self.formatSelect.addItem(self.tr('ED25519 (Recommended)'), 'ed25519')
         self.formatSelect.addItem(self.tr('RSA (Legacy)'), 'rsa')
@@ -78,5 +81,5 @@ class SSHAddWindow(SSHAddBase, SSHAddUI):
             'ssh_key': self.sshComboBox.currentData(),
             'encryption': self.encryptionComboBox.currentData(),
             'repo_url': self.repoURL.text(),
-            'password': self.passwordLineEdit.text()
+            'password': self.passwordLineEdit.text(),
         }
