@@ -2,21 +2,35 @@ import os
 import sys
 from datetime import datetime as dt
 from unittest.mock import MagicMock
-
 import pytest
 from peewee import SqliteDatabase
-
 import vorta
 import vorta.application
 import vorta.borg.jobs_manager
-from vorta.store.models import (ArchiveModel, BackupProfileModel,
-                                EventLogModel, RepoModel, RepoPassword,
-                                SchemaVersion, SettingsModel, SourceFileModel,
-                                WifiSettingModel)
+from vorta.store.models import (
+    ArchiveModel,
+    BackupProfileModel,
+    EventLogModel,
+    RepoModel,
+    RepoPassword,
+    SchemaVersion,
+    SettingsModel,
+    SourceFileModel,
+    WifiSettingModel,
+)
 from vorta.views.main_window import MainWindow
 
-models = [RepoModel, RepoPassword, BackupProfileModel, SourceFileModel,
-          SettingsModel, ArchiveModel, WifiSettingModel, EventLogModel, SchemaVersion]
+models = [
+    RepoModel,
+    RepoPassword,
+    BackupProfileModel,
+    SourceFileModel,
+    SettingsModel,
+    ArchiveModel,
+    WifiSettingModel,
+    EventLogModel,
+    SchemaVersion,
+]
 
 
 def pytest_configure(config):
@@ -32,7 +46,14 @@ def qapp(tmpdir_factory):
     mock_db = SqliteDatabase(str(tmp_db))
     vorta.store.connection.init_db(mock_db)
 
+    # Needs to be disabled before calling VortaApp()
+    if sys.platform == 'darwin':
+        cfg = vorta.store.models.SettingsModel.get(key='check_full_disk_access')
+        cfg.value = False
+        cfg.save()
+
     from vorta.application import VortaApp
+
     VortaApp.set_borg_details_action = MagicMock()  # Can't use pytest-mock in session scope
     VortaApp.scheduler = MagicMock()
 
@@ -46,7 +67,12 @@ def qapp(tmpdir_factory):
 @pytest.fixture(scope='function', autouse=True)
 def init_db(qapp, qtbot, tmpdir_factory):
     tmp_db = tmpdir_factory.mktemp('Vorta').join('settings.sqlite')
-    mock_db = SqliteDatabase(str(tmp_db), pragmas={'journal_mode': 'wal', })
+    mock_db = SqliteDatabase(
+        str(tmp_db),
+        pragmas={
+            'journal_mode': 'wal',
+        },
+    )
     vorta.store.connection.init_db(mock_db)
 
     default_profile = BackupProfileModel(name='Default')
@@ -67,8 +93,7 @@ def init_db(qapp, qtbot, tmpdir_factory):
     test_archive1 = ArchiveModel(snapshot_id='99998', name='test-archive1', time=dt(2000, 1, 1, 0, 0), repo=1)
     test_archive1.save()
 
-    source_dir = SourceFileModel(dir='/tmp/another', repo=new_repo, dir_size=100, dir_files_count=18,
-                                 path_isdir=True)
+    source_dir = SourceFileModel(dir='/tmp/another', repo=new_repo, dir_size=100, dir_files_count=18, path_isdir=True)
     source_dir.save()
 
     qapp.main_window.deleteLater()
@@ -105,6 +130,7 @@ def borg_json_output():
         stdout = open(f'tests/borg_json_output/{subcommand}_stdout.json')
         stderr = open(f'tests/borg_json_output/{subcommand}_stderr.json')
         return stdout, stderr
+
     return _read_json
 
 
