@@ -1,7 +1,7 @@
 import pytest
-from PyQt5 import QtCore
-import vorta.borg.borg_job
+from PyQt6 import QtCore
 import vorta.application
+import vorta.borg.borg_job
 
 
 def test_create_perm_error(qapp, borg_json_output, mocker, qtbot):
@@ -12,7 +12,7 @@ def test_create_perm_error(qapp, borg_json_output, mocker, qtbot):
     popen_result = mocker.MagicMock(stdout=stdout, stderr=stderr, returncode=0)
     mocker.patch.object(vorta.borg.borg_job, 'Popen', return_value=popen_result)
 
-    qtbot.mouseClick(main.createStartBtn, QtCore.Qt.LeftButton)
+    qtbot.mouseClick(main.createStartBtn, QtCore.Qt.MouseButton.LeftButton)
 
     qtbot.waitUntil(lambda: hasattr(qapp, '_msg'), **pytest._wait_defaults)
     assert qapp._msg.text().startswith("You do not have permission")
@@ -28,7 +28,7 @@ def test_create_lock(qapp, borg_json_output, mocker, qtbot):
     popen_result = mocker.MagicMock(stdout=stdout, stderr=stderr, returncode=0)
     mocker.patch.object(vorta.borg.borg_job, 'Popen', return_value=popen_result)
 
-    qtbot.mouseClick(main.createStartBtn, QtCore.Qt.LeftButton)
+    qtbot.mouseClick(main.createStartBtn, QtCore.Qt.MouseButton.LeftButton)
 
     qtbot.waitUntil(lambda: hasattr(qapp, '_msg'), **pytest._wait_defaults)
     assert "The repository at" in qapp._msg.text()
@@ -41,4 +41,4 @@ def test_create_lock(qapp, borg_json_output, mocker, qtbot):
     qtbot.waitUntil(lambda: main.createStartBtn.isEnabled(), **pytest._wait_defaults)  # Prevent thread collision
     qapp._msg.accept()
     exp_message_text = 'Repository lock broken. Please redo your last action.'
-    qtbot.waitUntil(lambda: main.progressText.text() == exp_message_text, **pytest._wait_defaults)
+    qtbot.waitUntil(lambda: exp_message_text in main.progressText.text(), **pytest._wait_defaults)
